export declare namespace schema {
    interface Template {
        readonly Resources?: Record<string, Resource>;
        readonly AWSTemplateFormatVersion?: string;
        readonly Description?: string;
        readonly Metadata?: Record<any, any>;
        readonly Parameters?: Record<string, Parameter>;
        readonly Rules?: Record<string, Rule>;
        readonly Mappings?: Record<string, Mapping>;
        readonly Conditions?: Record<string, Condition>;
        readonly Transform?: string | string[];
        readonly Outputs?: Record<string, Output>;
        readonly Hooks?: Record<string, Hook>;
        readonly Context?: Record<string, any>;
    }
    interface Resource {
        readonly Type: string;
        readonly Properties?: Record<string, CfnValue<any>>;
        readonly Condition?: string;
        readonly DependsOn?: string | string[];
        readonly DeletionPolicy?: 'Retain' | 'Delete' | 'Snapshot';
        readonly UpdateReplacePolicy?: 'Retain' | 'Delete' | 'Snapshot';
        readonly Metadata?: Record<string, any>;
        readonly CreationPolicy?: CreationPolicy;
        readonly UpdatePolicy?: UpdatePolicy;
        readonly Tags?: Tag[];
        readonly Overrides?: Override[];
        readonly Call?: CfnValue<any>;
    }
    interface CreationPolicy {
        readonly AutoScalingCreationPolicy?: AutoScalingCreationPolicy;
        readonly ResourceSignal?: ResourceSignal;
    }
    interface UpdatePolicy {
        [key: string]: any;
    }
    interface AutoScalingCreationPolicy {
        readonly MinSuccessfulInstancesPercent: number;
    }
    interface ResourceSignal {
        readonly Count: number;
        readonly Timeout: string;
    }
    interface Parameter {
        readonly Type: string;
        readonly Description?: string;
        readonly Default?: any;
        readonly AllowedValues?: any[];
        readonly AllowedPattern?: string;
        readonly ConstraintDescription?: string;
        readonly MaxLength?: number;
        readonly MinLength?: number;
        readonly MinValue?: number;
        readonly MaxValue?: number;
        readonly NoEcho?: boolean;
    }
    interface Rule {
    }
    interface Output {
        readonly Description?: string;
        readonly Value: CfnValue<string>;
        readonly Export?: {
            readonly Name: CfnValue<string>;
        };
        readonly Condition?: string;
    }
    interface Hook {
        readonly Type: string;
        readonly Properties?: Record<string, CfnValue<any>>;
    }
    interface Tag {
        readonly Key: string;
        readonly Value: string;
    }
    interface Override {
        readonly ChildConstructPath?: string;
        readonly Update?: {
            readonly Path: string;
            readonly Value: CfnValue<any>;
        };
        readonly Delete?: {
            readonly Path: string;
        };
        readonly RemoveResource?: boolean;
    }
    type Mapping = Record<string, any>;
    type CfnValue<A> = A | Intrinsic;
    type Intrinsic = Ref | FnBase64 | FnCidr | FnFindInMap | FnGetAZs | FnGetAtt | FnIf | FnImportValue | FnJoin | FnSelect | FnSplit | FnSub;
    type Ref = {
        Ref: string;
    };
    type FnBase64 = {
        'Fn::Base64': CfnValue<string>;
    };
    type FnCidr = {
        'Fn::Cidr': [string | FnSelect | Ref, number, number];
    };
    type FnFindInMap = {
        'Fn::FindInMap': [CfnValue<string>, CfnValue<string>, CfnValue<string>];
    };
    type FnGetAZs = {
        'Fn::GetAZs': string | Ref;
    };
    type FnGetAtt = {
        'Fn::GetAtt': string | [string, string | Ref];
    };
    type FnIf = {
        'Fn::If': [string, CfnValue<any>, CfnValue<any>];
    };
    type FnImportValue = {
        'Fn::ImportValue': CfnValue<string>;
    };
    type FnJoin = {
        'Fn::Join': [string, CfnValue<Array<CfnValue<string>>>];
    };
    type FnSelect = {
        'Fn::Select': [CfnValue<number>, CfnValue<string>];
    };
    type FnSplit = {
        'Fn::Split': [string, CfnValue<string>];
    };
    type FnSub = {
        'Fn::Sub': string | [string, Record<string, CfnValue<string>>];
    };
    type FnTransform = {
        'Fn::Transform': {
            readonly Name: string;
            readonly Parameters: Record<string, CfnValue<any>>;
        };
    };
    type Condition = FnEquals | FnAnd | FnNot | FnOr;
    type ConditionValue<A> = A | FnFindInMap | Ref;
    type FnAnd = {
        'Fn::And': Condition[];
    };
    type FnOr = {
        'Fn::Or': Condition[];
    };
    type FnNot = {
        'Fn::Not': [Condition];
    };
    type FnEquals = {
        'Fn::Equals': [ConditionValue<string>, ConditionValue<string>];
    };
}
