import * as reflect from 'jsii-reflect';
import { InitializerExpression, InstanceMethodCallExpression, StaticMethodCallExpression } from './callables';
import { EnumExpression, StaticPropertyExpression } from './enums';
import { DateLiteral } from './literals';
import { AnyTemplateExpression, VoidExpression } from './primitives';
import { ResolveReferenceExpression } from './references';
import { ResourceLike } from './resource-like';
import { StructExpression } from './struct';
import { ArrayExpression, BooleanLiteral, IntrinsicExpression, NullLiteral, NumberLiteral, ObjectExpression, StringLiteral, TemplateExpression } from '../parser/template';
export type TypedTemplateExpression = IntrinsicExpression | ResolveReferenceExpression | StringLiteral | NumberLiteral | BooleanLiteral | DateLiteral | NullLiteral | TypedArrayExpression | TypedObjectExpression | EnumExpression | StructExpression | StaticPropertyExpression | StaticMethodCallExpression | InstanceMethodCallExpression | InitializerExpression | VoidExpression | AnyTemplateExpression | ResourceLike;
export interface TypedArrayExpression extends ArrayExpression<TypedTemplateExpression> {
}
export interface TypedObjectExpression extends ObjectExpression<TypedTemplateExpression> {
}
export declare function assertExpressionForType<T extends TemplateExpression['type']>(x: TemplateExpression, type: T, typeRef: reflect.TypeReference): TemplateExpression & {
    type: T;
};
export declare function isExpressionShaped(x: unknown): x is TypedTemplateExpression;
export declare function assertExpressionShaped(x: unknown): TypedTemplateExpression;
export interface TypedTemplateOutput {
    readonly description?: string;
    readonly value: TypedTemplateExpression;
    readonly exportName?: TypedTemplateExpression;
    readonly conditionName?: string;
}
export declare function toTypedTemplateExpression(input: TemplateExpression): TypedTemplateExpression;
export declare function convertArray(xs: TemplateExpression[]): TypedTemplateExpression[];
export declare function convertObject(xs: Record<string, TemplateExpression>): Record<string, TypedTemplateExpression>;
